jquery.multi-select.js - user-friendlier select multiple replacement
Description: A tiny jQuery plugin which make your select with multiple attribute not suck !

Download

# jquery.multi-select.js

## Making your <select> with multiple attribute not suck !

The purpose of this plugin is to be a drop-in replacement for your <select> with multiple attribute.

- It works in an unobtrusive fashion.
- Entirely styleable with CSS.
- No extra HTML markup needed.
- You can add as many select as you want on a single page.
- It provides some callbacks.
- Methods can be called from outside.
- Entirely open sourced.
- Tiny code (< 3KB).
- Tested on: Firefox 3/4, chrome 10, safari 5, IE 7/8/9.
- Works with jQuery 1.4+

### Usage

Note: because of the new prop() method, if you use jquery 1.6+ use jquery.multi-select.1.6.js, if not use jquery.multi-select.js.

Add a css class to all multiple select you want to customize.

          <select multiple='multiple' class='your_class' name='your_name[]'>
            <option value='fr'>France</option>
            ...
          </select>

Add following code to your project

          $(function(){
            $('.your_class').multiSelect();
          });

### Contributors

- lou (Author)
- Serophos